RegNo | FundType | Custodian | Guarantor | Manager | Name | WebSite
--- | --- | --- | --- | --- | --- | ---
11878 | در سهام | موسسه حسابرسي وانيا نيك تدبير | ندارد | سبدگردان داريوش | قابل معامله ثروت داریوش | http://servat.dariush.fund
10765 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي شاخص انديشان | ندارد | تأمين سرمايه نوين | مشترک آتیه نوین | http://www.atiehnovin.ir
10845 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي فريوران | بانك كارآفرين | كارگزاري بانك كارآفرين | آرمان کارآفرین | http://akfund.com
11477 | در سهام | موسسه حسابرسي فريوران راهبرد | ندارد | مشاور سرمايه گذاري پرتو آفتاب كيان | آوای سهام کیان | http://www.asmfund.ir
11756 | در سهام | حسابرسي شاخص انديشان | ندارد | سبدگردان آرمان اقتصاد | اتحاد آرمان اقتصاد | http://akfund.com
11364 | بازارگردانی | شركت مشاور سرمايه گذاري ايرانيان تحليل فارابي | ندارد | كارگزاري بانك تجارت | اختصاصی بازارگردان تجارت ایرانیان اعتماد | http://www.tejarat-mmf.com/
11419 | بازارگردانی | موسسه حسابرسي شاخص انديشان | ندارد | شركت مشاور سرمايه گذاري ارزش پرداز آريان | اختصاصی بازارگردانی انديشه زرين پاسارگاد | http://azpfund.com
11365 | بازارگردانی | موسسه حسابرسي فاطر | ندارد | كارگزاري بورس بهگزين | اختصاصی بازارگردانی بانک سینا | http://bxf4s.rhbroker.com/index.do
11443 | بازارگردانی | موسسه حسابرسي و خدمات مديريت ارقام نگر آريا | ندارد | كارگزاري بانك ملي | اختصاصی بازارگردانی پست بانک ایران | http://tsf3s.rhbroker.com/
11759 | بازارگردانی | موسسه حسابرسي بهراد مشار | ندارد | شركت مشاور سرمايه گذاري ترنج | اختصاصی بازارگردانی تاک دانا | http://www.tak.fund/
11786 | بازارگردانی | شركت مشاوره سرمايه گذاري سهم آشنا | ندارد | شركت سرمايه گذاري توسعه نور دنا | اختصاصی بازارگردانی حامی اول | www.avalhami.ir
11858 | در سهام | وانيا نيك تدبير | ندارد | سبدگردان داريوش | اختصاصی بازارگردانی دارا داریوش | http://dara.dariush.fund/
11435 | بازارگردانی | شركت مشاور سرمايه گذاري سهم آشنا | ندارد | گروه سرمايه گذاري ميراث فرهنگي و گردشگري ايران | اختصاصی بازارگردانی گروه گردشگری ایرانیان | http://www.gfund.ir/
11421 | در اوراق بهادار با درآمد ثابت | حسابرسي هوشيار مميز | ندارد | شركت مشاورسرمايه گذاري آرمان آتي | ارزش آفرین گلرنگ | www.golrangfund.com
10911 | در اوراق بهادار با درآمد ثابت | مشاور سرمايه گذاري ايرانيان تحليل فارابي | بانك دي | كارگزاري بانك دي | ارزش آفرینان دی | http://afdayfund.ir
10706 | در سهام | حسابرسي و خدمات مديريت سامان پندار | ندارد | سبدگردان آسال | ارزش کاوان آینده | http://arzeshkavanfund.ir
10897 | مختلط | موسسه حسابرسي و خدمات مديريت آزموده كاران | ندارد | شركت سبدگردان پاداش سرمايه | ارمغان یکم ملل | http://www.armaghanemelal.com
11738 | در اوراق بهادار با درآمد ثابت | مؤسسه حسابرسي بهراد مشار | ندارد | سبدگردان اعتبار مدير صندوق | اعتبار آفرین ایرانیان | http://etebarafarin.com
11706 | در سهام | موسسه حسابرسي بهرادمشار | ندارد | شركت سبدگردان اعتبار | اعتبار سهام ایرانیان | http://www.etebarsaham.com
11449 | در اوراق بهادار با درآمد ثابت | شركت مشاور سرمايه گذاري سهم آشنا | ندارد | شركت سبدگردان نوين نگر آسيا | اعتماد ملل | http://msfs.rhbroker.com/
11517 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي و خدمات مديريت ارقام نگر آريا | ندارد | كارگزاري بانك ملي ايران | اعتماد کارگزاری بانک ملی ایران | http://www.etemadbmifund.com
11692 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي شاخص انديشان | ندارد | شركت مشاور سرمايه گذاري ترنج | افرا نماد پایدار | www.afra.fund
11461 | در سهام | شركت ارقام نگر آريا | ندارد | كارگزاري بانك خاورميانه (سهامي خاص) | افق روشن بانک خاورمیانه | orfund.mebbco.com
11741 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي هوشيار مميز | ندارد | سبدگردان كوروش | الماس کوروش | http://www.kouroshfund.com
11049 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي رازدار | ندارد | شركت سبدگردان سهم آشنا | امین آشنا ایرانیان | http://iafi.ir/
10929 | در اوراق بهادار با درآمد ثابت | شركت مشاور سرمايه گذاري ايرانيان تحليل فارابي | بانك سامان | شركت تأمين سرمايه امين | امین سامان | www.aminsaman.com
11701 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي و مديريت ارقام نگر آريا | ندارد | شركت سبدگردان آميتيس | اندوخته آمیتیس | http://fund1-amitispm.ir
11145 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي و خدمات مديريت ارقام نگر آريا | بانك صادرات ايران | شركت تامين سرمايه سپهر | اندوخته پایدار سپهر | http://www.andukhtesepehr.com/
11334 | در سهام | موسسه حسابرسي فريوران راهبرد | ندارد | مدير-كارگزاري خبرگان سهام | اندیشه خبرگان سهام | www.khobreganfund.com
11518 | در اوراق بهادار با درآمد ثابت | شركت مشاور سرمايه گذاري ايرانيان تحليل فارابي | ندارد ? ندارد | شركت سبدگردان توسعه فيروزه | با درآمد ثابت فیروزه آسیا | www.firouzehfixetf.com
11302 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي رازدار | ندارد | سبدگردان كاريزما | با درآمد ثابت کاریزما | http://charismafixedincome.com
11513 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي رازدار | ندارد | سبدگردان كاريزما | با درآمد ثابت کمند | www.kamandfixedincome.com
10782 | در سهام | موسسه حسابرسي فريوران راهبرد | ندارد | كارگزاري بانك كشاورزي | باران کارگزاری بانک کشاورزی | http://fund.agribourse.com
11884 | در سهام | موسسه حسابرسي و خدمات مالي و مديريت ايران مشهود | ندارد | سبدگردان زاگرس | بازارگردانی آوای زاگرس | http://www.azmmfund.ir/
11397 | بازارگردانی | مؤسسه حسابرسي فريوران راهبرد | ندارد | تأمين سرمايه سپهر | بازارگردانی چند سهمی سپهر بازار سرمایه | http://sepehrbs.ir/
11447 | بازارگردانی | موسسه حسابرسي شاخص انديشان | نامشخص | شركت تامين سرمايه تمدن | بازارگردانی صنعت مس | http://www.mellimesmfund.com
11316 | بازارگردانی | حسابرسي آزمودگان | ندارد | شركت تأمين سرمايه تمدن | بازارگردانی گسترش صنعت دارو | http://bkf3s.irbroker2.com/index.do
11008 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي آزمودگان | ندارد | مشاور سرمايه گذاري هدف حافظ | بانک ایران زمین | http://www.izfund.ir
10869 | در سهام | مشاور سرمايه گذاري ايرانيان تحليل فارابي | بانك دي | كارگزاري بانك دي | بانک دی | http://www.dayfund.ir
10883 | در اوراق بهادار با درآمد ثابت | مشاور سرمايه گذاري ايرانيان تحليل فارابي | بانك گردشگري | سبدگردان سرآمد بازار | بانک گردشگری | http://www.gbfund.ir
11394 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي و خدمات مديريت آزموده كاران | ندارد | سبدگردان پاداش سرمايه | پاداش سرمایه بهگزین | http://padashfixedincome.com/index.do
11416 | در اوراق بهادار با درآمد ثابت | مؤسسه حسابرسي بهراد مشار |  | تأمين سرمايه سپهر | پارند پايدار سپهر | http://www.parandfund.com/
11530 | طلا | موسسه حسابرسي و خدمات مديريت آزموده كاران | ندارد | تأمين سرمايه اميد | پشتوانه سکه طلای زرافشان امید ایرانیان | http://www.omidgoldfund.ir
11509 | طلا | موسسه حسابرسي فريوران راهبرد | ندارد | تامين سرمايه لوتوس پارسيان | پشتوانه طلای لوتوس | http://www.lotusgoldfund.capital/
11158 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي آزموده كاران | تامين سرمايه لوتوس پارسيان | تامين سرمايه لوتوس پارسيان | پیروزان | http://www.pirouzanfund.com
11661 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي فراز مشاور ديلمي پور | ندارد | مشاورسرمايه گذاري فراز ايده نوآفرين تك (فاينتك) | پیشگامان سرمایه نوآفرین | http://www.psnfund.com
10885 | مختلط | موسسه حسابرسي سامان پندار | بانك آينده | كارگزاري بانك آينده | تجربه ايرانيان | http://www.tajrobeiranian.ir
11305 | مختلط | موسسه حسابرسي فراز مشاور ديلمي پور | ندارد | شركت كارگزاري بانك توسعه صادرات | توسعه پست بانک | http://fundtpb.com
11385 | در اوراق بهادار با درآمد ثابت | مشاور سرمايه گذاري ديدگاهان نوين | بانك توسعه تعاون | شركت كارگزاري صبا تامين | توسعه تعاون صبا | http://stfs.rhbroker.com/index.do
11420 | در اوراق بهادار با درآمد ثابت | مشاور سرمايه گذاري ايرانيان تحليل فارابي | ندارد | مشاور سرمايه گذاري نيكي گستر | توسعه سرمایه نیکی | http://ngf3s.rhbroker.com/index.do
10864 | در سهام | موسسه حسابرسي فراز مشاور ديلمي پور | ندارد | شركت تامين سرمايه تمدن | توسعه صادرات | http://fund.edbibroker.com/index.do
11521 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي رازدار | ندارد | شركت تامين سرمايه تمدن | توسعه فراز اعتماد | http://toseefarazfund.com
11327 | در سهام | موسسه حسابرسي فريوران راهبرد |  | تامين سرمايه لوتوس پارسيان | ثروت آفرين پارسيان | http://pbfetfs.rhbroker.com
11675 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي شاخص انديشان | ندارد | مشاور سرمايه گذاري ديدگاهان نوين | ثروت ستارگان | http://starsfof.ir/
11746 | جسورانه | موسسه حسابرسي و خدمات مديريت سامان پندار | ندارد | پردازش اطلاعات مالي پارت | جسورانه پارتیان | http://investors.partianvc.com
11479 | جسورانه | موسسه حسابرسي فريوران راهبرد | ندارد ? ندارد | تامين سرمايه لوتوس پارسيان | جسورانه رويش لوتوس | www.royeshvcfund.ir
10784 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي و خدمات مديريت رهيافت و همكاران | ندارد | سبدگردان سهم آشنا | حکمت آشنا ایرانیان | http://www.afund.ir
11753 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي هدف نوين نگر | ندارد | شركت سبدگردان ايساتيس پويا كيش | خاتم ایساتیس پویا | http://etf.isatispm.com/Home/Index
11556 | طلا | موسسه حسابرسي هوشيار مميز | ندارد ? ندارد | مشاور سرمايه گذاري پرتو آفتاب كيان | در اوراق بهادار مبتنی بر سکه طلای کیان | http://www.kianfunds3.com
11551 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي بهمند | ندارد | شركت سبد گردان فارابي | دوم اکسیر فارابی | http://exir2.irfarabi.com/
11268 | در سهام | مؤسسه حسابرسي و خدمات مديريت ارقام نگر آريا | ندارد | شركت سبدگردان نو ويرا | ذوب آهن نوویرا | http://www.esmf.ir
11142 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي شاخص انديشان | تامين سرمايه بانك مسكن | شركت كارگزاري بانك مسكن | ره آورد آباد مسکن | http://maskanfund.ir/
11285 | در سهام | موسسه حسابرسي فريوران راهبرد | تامين سرمايه لوتوس پارسيان | تامين سرمايه لوتوس پارسيان | زرین پارسیان | www.parsianzarinfund.com
11853 | در سهام | مؤسسه حسابرسي و خدمات مالي و مديريت ايران مشهود | ندارد | شركت سبدگردان آگاه سهامي خاص | زمرد آگاه | http://zomorodfund.ir/
11665 | در اوراق بهادار با درآمد ثابت | مؤسسه حسابرسي و خدمات مديريت ارقام نگر آريا | ندارد | شركت سبدگردان نوويرا | زمرد نو ویرا ذوب آهن | www.nsfmf.ir
10855 | در سهام | موسسه حسابرسي و خدمات مالي فاطر | بانك صادرات ايران | شركت تامين سرمايه سپهر | سپهر اول | http://www.sepehr1fund.com
11820 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي بهراد مشار | ندارد | شركت تامين سرمايه دماوند | سپید دماوند | http://www.sepiddamavandfund.ir
11223 | در سهام | موسسه حسابرسي رازدار | ندارد | سبدگردان سهم آشنا | سهم آشنا | www.samf.ir
11856 | در سهام | مؤسسه حسابرسي و خدمات مديريت سامان پندار | ندارد | سبدگردان كاريزما | سکه طلا کهربا | kahroba.charisma.ir
10825 | در سهام | موسسه حسابرسي و خدمات مديريت آزموده كاران | ندارد | سبدگردان سينا(سهامي خاص) | سینا | http://www.sinamutualfund.com
11763 | در سهام | موسسه حسابرسي رازدار | ندارد | شركت سبدگردان سهم آشنا | شاخصی بازار آشنا | www.indexfund.ir
10835 | در سهام | شركت مشاور سرمايه گذاري سهم آشنا | ندارد | كارگزاري بانك كارآفرين | شاخصی کارآفرین | http://karafarinindexfund.com
11681 | بازارگردانی | موسسه حسابرسي ارقام نگر آريا | ندارد ? ندارد | سبدگردان فارابي | صندوق اختصاصی بازارگردانی الگوریتمی امید فارابی | http://mmxo.irfarabi.com/
11287 | بازارگردانی | موسسه حسابرسي بهمند | ضامن | شركت تامين سرمايه نوين | صندوق بازارگرداني اختصاصی نوين پيشرو | www.novinpishro.com
11306 | بازارگردانی | موسسه حسابرسي رازدار | ضامن | شركت كارگزاري بانك سپه | صندوق بازارگرداني حکمت ایرانیان یکم | http://www.hifund.ir/index.do
11799 | بازارگردانی | موسسه حسابرسی و خدمات مدیریت آزموده کاران | نامشخص نامشخص | سبدگردان تصمیم نگار ارزش آفرینان | صندوق بازارگردانی اختصاصی تصمیم ساز | tasmimsazfund.ir
11286 | بازارگردانی | موسسه حسابرسي فريوران راهبرد | ندارد | تامين سرمايه لوتوس پارسيان | صندوق سرمايه گذاري اختصاصی بازارگردانی اميد لوتوس پارسيان | http://mpbf.rhbroker.com/
11687 | بازارگردانی | مشاور سرمايه گذاري سهم آشنا | ندارد | شركت سبدگردان ايساتيس پويا | صندوق سرمايه گذاري اختصاصی بازارگردانی ایساتیس پویا | http://mmf.isatispm.com/
11534 | بازارگردانی | موسسه حسابرسي شاخص انديشان | ندارد | كارگزاري بانك صنعت و معدن | صندوق سرمايه گذاري اختصاصی بازارگردانی نماد صنعت و معدن | http://samf.rhbroker.com/
11329 | در سهام | موسسه حسابرسي رازدار | ندارد | سبدگردان سهم آشنا | صندوق سرمايه گذاري بازارگردانی مپنا ایرانیان | www.novinpishro.com
10591 | در سهام | موسسه حسابرسي فراز مشاور ديلمي پور | ندارد | شركت مشاور سرمايه گذاري هدف حافظ | صندوق سرمايه گذاري مشترک کارگزاري حافظ | http://mutualfund.hafezbourse.com
11776 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسی و خدمات مالی و مدیریت ایران مشهود | نامشخص نامشخص | سبدگردان زاگرس | صندوق سرمایه گذاری آوای فردای زاگرس | afzfund.ir
11752 | بازارگردانی | موسسه حسابرسي شاخص انديشان | ندارد | شركت سبدگردان اقتصاد بيدار | صندوق سرمایه گذاری اختصاصی بازارگرداني نهایت اندیش اقتصاد بیدار | www.Bazargardan.ebb.ir
11777 | بازارگردانی | موسسه حسابرسی ارقام نگر آریا | نامشخص نامشخص | شرکت سبدگردان آسمان | صندوق سرمایه گذاری اختصاصی بازارگردانی آسمان زاگرس | http://azmfund.ir
11807 | بازارگردانی | داریاروش | نامشخص نامشخص | سبدگردان آرمان اقتصاد | صندوق سرمایه گذاری اختصاصی بازارگردانی اتحاد بازار سرمایه | ettehadbazarsarmaye.ir
11769 | بازارگردانی | مشاور سرمایه گذاری ایرانیان تحلیل فارابی | نامشخص نامشخص | شرکت تامین سرمایه امین | صندوق سرمایه گذاری اختصاصی بازارگردانی امین | aminfunds.ir
11764 | بازارگردانی | موسسه حسابرسی کاربرد تحقیق | نامشخص نامشخص | سرمایه گذاری توسعه توکا | صندوق سرمایه گذاری اختصاصی بازارگردانی توسعه فولاد مبارکه | fund.tukadev.ir
11668 | بازارگردانی | مشاور سرمايه گذاري سهم آشنا | ندارد | شركت سرمايه گذاري مهرگان تامين پارس | صندوق سرمایه گذاری اختصاصی بازارگردانی مهرگان | http://mehreganfund.com/
11405 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسی شاخص اندیشان | بانک توسعه صادرات ایران | تامین سرمایه تمدن | صندوق سرمایه گذاری اندوخته توسعه صادرات آرمانی | http://www.edbifund.net
11099 | در سهام | موسسه حسابرسی آزمودگان | شرکت تامین سرمایه تمدن | شرکت تامین سرمایه تمدن | صندوق سرمایه گذاری ثروت آفرین تمدن | http://servatfund.ir/
11808 | جسورانه | موسسه حسابرسی آگاهان و همکاران |  | گروه سرمایه گذاری توسعه صنعتی ایران | صندوق سرمایه گذاری خصوصی ثروت آفرین فیروزه | firouzehpe.ir
11495 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسی رازدار |  | شرکت سبدگردان سرآمد بازار | صندوق سرمایه گذاری درآمد ثابت سرآمد | https://www.saramadfixedfund.com
10919 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسی هوشیار ممیز | بانک شهر | تامین سرمایه تمدن | صندوق سرمایه گذاری گنجینه زرین شهر | http://ganjinehzarinshahr.com
11188 | مختلط | حسابرسی آزمودگان | تامین سرمایه تمدن (سهامی خاص) | تامین سرمایه تمدن (سهامی خاص) | صندوق سرمایه گذاری گوهر نفیس تمدن | www.armanshahrfund.com
10895 | در اوراق بهادار با درآمد ثابت | ایرانیان تحلیل فارابی | بانک ملت (سهامی عام) | تامین سرمایه بانک ملت | صندوق سرمایه‌گذاری آتیه ملت | atmellatfund.com
11172 | مختلط | حسابرسی هوشیار ممیز | ندارد | شرکت مشاور سرمایه گذاری آرمان آتی | صندوق سرمایه‌گذاری آرمان سپهر آشنا | asaetf.ir
11195 | در سهام | موسسه حسابرسی و خدمات مدیریت آزموده کاران | ندارد | شرکت سبدگردان آسمان | صندوق سرمایه‌گذاری آسمان آرمانی سهام | asasfund.ir
11454 | در سهام | موسسه حسابرسی هوشیار ممیز | ندارد | مشاور سرمایه گذاری پرتو آفتاب کیان | صندوق سرمایه‌گذاری آهنگ سهام کیان | kianfunds4.ir
11091 | بازارگردانی | مشاور سرمایه گذاری ایرانیان تحلیل فارابی | ندارد | مشاور سرمایه گذاری آرمان آتی | صندوق سرمایه‌گذاری اختصاصی بازارگردانی آرمان اندیش | armanandishfund.com
11386 | بازارگردانی | موسسه حسابرسی خدمات مدیریت داریاروش | ندارد | شرکت کارگزاری بانک انصار | صندوق سرمایه‌گذاری اختصاصی بازارگردانی آرمان انصار | armanansarfund.com
11822 | بازارگردانی | موسسه حسابرسی آتیه اندیش نمودگر | نامشخص نامشخص | کارگزاری آرمان تدبیر نقش جهان | صندوق سرمایه‌گذاری اختصاصی بازارگردانی آرمان تدبیر نقش جهان | armanbrokerfund.ir
11553 | بازارگردانی | موسسه حسابرسی فراز مشاور دیلمی پور | نامشخص نامشخص | کارگزاری صبا جهاد | صندوق سرمایه‌گذاری اختصاصی بازارگردانی ارزش آفرین صندوق بازنشستگی کشوری | arzeshafarinfund.com
11281 | بازارگردانی | موسسه حسابرسی آزمودگان | نامشخص نامشخص | مشاور سرمایه گذاری هدف حافظ | صندوق سرمایه‌گذاری اختصاصی بازارگردانی افتخار حافظ | ehafezfund.com
11339 | بازارگردانی | موسسه حسابرسی و خدمات مدیریت آزموده‌کاران |  | تامین سرمایه امید | صندوق سرمایه‌گذاری اختصاصی بازارگردانی امید ایرانیان | smomidfund.ir
11324 | بازارگردانی | موسسه حسابرسی و بهبود سیستم های مدیریت حسابرسین | ندارد | کارگزاری بهمن | صندوق سرمایه‌گذاری اختصاصی بازارگردانی بهمن گستر | bahmangostarfund.com
11710 | بازارگردانی | موسسه حسابرسی و بهبود سیستم های مدیریت حسابرسین | ندارد | شرکت کارگزاری سرمایه گذاری ملی ایران | صندوق سرمایه‌گذاری اختصاصی بازارگردانی توسعه سهام نیکی | nicibfund.ir
11346 | بازارگردانی | شرکت مشاور سرمایه گذاری سهم آشنا | ندارد | شرکت سرمایه گذاری مدیریت سرمایه مدار | صندوق سرمایه‌گذاری اختصاصی بازارگردانی توسعه ملی | fund.tmgic.ir
11688 | بازارگردانی | موسسه حسابرسی فریوران راهبرد | نامشخص نامشخص | کارگزاری خبرگان سهام | صندوق سرمایه‌گذاری اختصاصی بازارگردانی خبرگان اهداف | khobreganmmf.com
11664 | بازارگردانی | مؤسسه حسابرسی و خدمات مدیریت سامان پندار |  | سرمایه گذاری مدبران اقتصاد | صندوق سرمایه‌گذاری اختصاصی بازارگردانی خلیج فارس | pgfund.ir
11446 | بازارگردانی | موسسه حسابرسی ایرانیان تحلیل فارابی | ندارد - | کارگزاری بانک دی | صندوق سرمایه‌گذاری اختصاصی بازارگردانی گروه دی | daygroupfund.ir
11295 | بازارگردانی | موسسه حسابرسی وخدمات مدیریت ارقام نگر آریا | ندارد | شرکت کارگزاری بانک صادرات ایران | صندوق سرمایه‌گذاری اختصاصی بازارگردانی گنجینه سپهر صادرات | ganjinehsepehrfund.com
11607 | بازارگردانی | بهراد مشار | ندارد | سرمایه گذاری توسعه گوهران امید | صندوق سرمایه‌گذاری اختصاصی بازارگردانی گوهرفام امید | fund.goharanomid.ir
11813 | بازارگردانی | موسسه حسابرسی بهراد مشار | نامشخص نامشخص | تامین سرمایه دماوند | صندوق سرمایه‌گذاری اختصاصی بازارگردانی لاجورد دماوند | http://damavandfunds.ir/
11617 | بازارگردانی | موسسه حسابرسی فراز مشاور دیلمی پور | نامشخص نامشخص | شرکت سبد گردان انتخاب مفید | صندوق سرمایه‌گذاری اختصاصی بازارگردانی مفید | mofidmmf.com
11798 | بازارگردانی | موسسه حسابرسی و خدمات مدیریت آزموده کاران | نامشخص نامشخص | سبدگردان داریک پارس | صندوق سرمایه‌گذاری اختصاصی بازارگردانی میزان داریک |
11633 | بازارگردانی | مشاور سرمایه‌گذاری سهم آشنا | نامشخص نامشخص | کارگزاری آبان | صندوق سرمایه‌گذاری اختصاصی بازارگردانی هوشمند آبان | smart.aban.net
11407 | بازارگردانی | حسابرسی آزمودگان | ندارد | سبدگردان الگوریتم | صندوق سرمایه‌گذاری اختصاصی بازارگردانی کوشا الگوریتم | tsfund.ir
11828 | بازارگردانی | موسسه حسابرسی و خدمات مدیریت آزموده کاران |  | سبدگردان هامرز | صندوق سرمایه‌گذاری اختصاصی بازارگردانی یکم هامرز | yekom.hummers.ir
11713 | جسورانه | موسسه حسابرسی فراز مشاور دیلمی پور | نامشخص نامشخص | مشاور سرمایه گذاری فراز ایده نوآفرین تک | صندوق سرمایه‌گذاری اعتبار سرمایه نو آفرین | esnfund.com
11233 | در سهام | موسسه حسابرسی هوشیار ممیز | نامشخص نامشخص | شرکت تامین سرمایه بانک ملت | صندوق سرمایه‌گذاری افق ملت | ofoghmellat.ir
11161 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسی هوشیار ممیز | ندارد | تأمین سرمایه امین | صندوق سرمایه‌گذاری امین انصار | aminansar.com
10778 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسی هوشیار ممیز | ندارد | شرکت تامین سرمایه امین | صندوق سرمایه‌گذاری امین ملت | aminmellat.com
11460 | در اوراق بهادار با درآمد ثابت | مشاور سرمایه گذاری ایرانیان تحلیل فارابی |  | تأمین سرمایه امین | صندوق سرمایه‌گذاری امین یکم فردا | aminfarda.com
11014 | در اوراق بهادار با درآمد ثابت | ایرانیان تحلیل فارابی | بانک ملت (سهامی عام) | تامین سرمایه بانک ملت | صندوق سرمایه‌گذاری اندوخته ملت | andookhtehmellat.ir
11075 | در اوراق بهادار با درآمد ثابت | شرکت مشاور سرمایه گذاری سهم آشنا | بانک ملت (سهامی عام) | تامین سرمایه بانک ملت | صندوق سرمایه‌گذاری اوج ملت | owjmellat.ir
11383 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسی و خدمات مدیریت آزموده کاران | بانک انصار | تامین سرمایه امید | صندوق سرمایه‌گذاری با درآمد ثابت امید انصار | omidansarfund.com
11343 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسی آزموده کاران | تامین سرمایه امید | تامین سرمایه امید | صندوق سرمایه‌گذاری با درآمد ثابت گنجینه امید ایرانیان | http://ganjinehomidfund.ir/
11391 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسی و خدمات مدیریت ارقام نگر آریا | ندارد | سبدگردان نوین نگر آسیا | صندوق سرمایه‌گذاری با درآمد ثابت مشترک نوین نگر آسیا | novinnegarfund.com
11500 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسی شاخص اندیشان | نامشخص نامشخص | تامین سرمایه کاردان | صندوق سرمایه‌گذاری با درآمد ثابت نگین سامان | neginsamanfund.ir
11310 | در اوراق بهادار با درآمد ثابت | شرکت مشاور سرمایه گذاری ایرانیان تحلیل فارابی | ندارد | شرکت تأمین سرمایه کاردان | صندوق سرمایه‌گذاری با درآمد ثابت کاردان | www.iran-kfunds1.ir
11379 | در اوراق بهادار با درآمد ثابت | مشاور سرمایه‌گذاری سهم آشنا | ندارد ندارد | کارگزاری آبان | صندوق سرمایه‌گذاری با درآمد ثابت کوثر یکم | kosar1fund.com
11836 | بازارگردانی | مؤسسه حسابرسی فراز مشاور دیلمی پور | نامشخص نامشخص | کارگزاری سرمایه و دانش | صندوق سرمایه‌گذاری بازارگردانی اختصاصی پرگار | pargarfund.ir
11618 | بازارگردانی | موسسه حسابرسی رازدار | ندارد | سبد گردان کاریزما | صندوق سرمایه‌گذاری بازارگردانی اکسیر سودا | esodammf.com
11055 | در سهام | شرکت مشاور سرمایه گذاری ایرانیان تحلیل فارابی | بانک توسعه تعاون | شرکت کارگزاری بانک رفاه | صندوق سرمایه‌گذاری بانک توسعه تعاون | trfund.ir
11367 | در اوراق بهادار با درآمد ثابت | حسابرسی هوشیار ممیز | ندارد | شرکت تامین سرمایه تمدن (سهامی خاص) | صندوق سرمایه‌گذاری پاداش سهامداری توسعه یکم | sepasetf.com
11540 |  | تامین سرمایه تمدن | نامشخص نامشخص | شرکت مشاور سرمایه گذاری آرمان آتی | صندوق سرمایه‌گذاری پروژه آرمان پرند مپنا | apmprojectfund.com
11312 | در سهام | موسسه حسابرسی شاخص اندیشان | ندارد | شرکت تأمین سرمایه کاردان | صندوق سرمایه‌گذاری تجارت شاخصی کاردان | iran-kfunds3.ir
11215 | در سهام | موسسه حسابرسی رازدار | ندارد | شرکت سبد گردان انتخاب مفید | صندوق سرمایه‌گذاری توسعه اندوخته آینده | atlasetf.com
10762 | مختلط | موسسه حسابرسی رازدار | ندارد | سبد گردان انتخاب مفید | صندوق سرمایه‌گذاری توسعه ممتاز | momtazfund.com
11277 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسی رازدار | ندارد | شرکت سبد گردان انتخاب مفید | صندوق سرمایه‌گذاری ثابت حامی | hamifund.com
11562 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسی رازدار | ندارد - | شرکت سبدگردان انتخاب مفید | صندوق سرمایه‌گذاری ثابت نامی مفید | namifund.com
11823 | در سهام | موسسه حسابرسی و خدمات مدیریت آزموده کاران | نامشخص نامشخص | سبدگردان هامرز | صندوق سرمایه‌گذاری ثروت هامرز | servat.hummers.ir
11797 | جسورانه | موسسه حسابرسی آزمون پرداز | نامشخص نامشخص | شرکت مشاور سرمایه گذاری دیدگاهان نوین | صندوق سرمایه‌گذاری جسورانه ستاره برتر |
11603 | مختلط | موسسه حسابرسی هوشیار ممیز | این نوع صندوق ندارد. | شرکت سرمایه‌گذاری و خدمات مدیریت صندوق بازنشستگی کشوری | صندوق سرمایه‌گذاری جسورانه فناوری بازنشستگی | icpfvc.ir
11726 | جسورانه | مؤسسه حسابرسی بهراد مشار |  | شرکت گروه سرمایه گذاری توسعه صنعتی ایران | صندوق سرمایه‌گذاری جسورانه فیروزه | firouzehvcfund.com
11480 | جسورانه | حسابرسی بهراد مشار | این نوع صندوق ندارد. | شرکت مشاورسرمایه گذاری آرمان آتی (سهامی خاص ) | صندوق سرمایه‌گذاری جسورانه یکم آرمان آتی | armanativcfund1.com
11586 | طلا | موسسه حسابرسی رازدار | ندارد | شرکت سبد گردان انتخاب مفید | صندوق سرمایه‌گذاری در اوراق بهادار مبتنی بر سکه طلای مفید | ayaretf.com
11309 | در سهام | موسسه حسابرسی شاخص اندیشان | شرکت تأمین سرمایه کاردان | شرکت تأمین سرمایه کاردان | صندوق سرمایه‌گذاری سهام بزرگ کاردان | www.iran-kfunds2.ir
11308 | در سهام | موسسه حسابرسی آگاهان و همکاران | ندارد | سبدگردان توسعه فیروزه | صندوق سرمایه‌گذاری شاخص سی شرکت بزرگ فیروزه | iranetf.ir
10789 | در سهام | موسسه حسابرسی آگاهان و همکاران | سرمایه گذاری توسعه صنعتی ایران | سبدگردان توسعه فیروزه | صندوق سرمایه‌گذاری فیروزه موفقیت | firoozehfund.com
11841 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسی و خدمات مدیریت ازموده کاران | نامشخص نامشخص | سبدگردان سینا | صندوق سرمایه‌گذاری قابل معامله سپهر سودمند سینا | sinaetf.ir
11621 | در اوراق بهادار با درآمد ثابت | حسابرسی شاخص اندیشان | نامشخص نامشخص | شرکت سبد گردان الماس | صندوق سرمایه‌گذاری گنجینه الماس بیمه دی | almasday.com
10781 | در سهام | مشاور سرمایه گذاری ایرانیان تحلیل فارابی |  | کارگزاری بانک رفاه کارگران | صندوق سرمایه‌گذاری گنجینه رفاه | grfund.ir
11499 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسی هوشیار ممیز | ندارد | شرکت تامین سرمایه امین | صندوق سرمایه‌گذاری گنجینه یکم آوید | ganjinehavid1.com
11736 | در سهام | موسسه حسابرسی فراز مشاور دیلمی پور | نامشخص نامشخص | مشاور سرمایه گذاری فراز ایده نوآفرین تک | صندوق سرمایه‌گذاری مدیریت ثروت صندوق بازنشستگی کشوری | modirfund.ir
11626 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسی و خدمات مدیریت آزموده کاران | ندارد ندارد | شرکت سبدگردان آسمان | صندوق سرمایه‌گذاری مشترک آسمان امید | asemanomid.com
11157 | مختلط | موسسه حسابرسی و خدمات مدیریت آزموده کاران | ندارد ندارد | شرکت سبدگردان آسمان | صندوق سرمایه‌گذاری مشترک آسمان خاورمیانه | akmfund.ir
11087 | در سهام | موسسه حسابرسی آزموده کاران | ندارد | شرکت سبدگردان آسمان | صندوق سرمایه‌گذاری مشترک آسمان یکم | aymfund.ir
11132 | در سهام | موسسه حسابرسی فراز مشاور دیلمی پور | ندارد | سبد گردان انتخاب مفید | صندوق سرمایه‌گذاری مشترک امید توسعه | omid-fund.com
11173 | در سهام | موسسه حسابرسی هوشیار ممیز | شرکت تامین سرمایه امین | شرکت تامین سرمایه امین | صندوق سرمایه‌گذاری مشترک امین آوید | aminavidfund.com
10753 | در سهام | مشاور سرمایه گذاری سهم آشنا | سرمایه گذاری ایساتیس پویا | سبدگردان ایساتیس پویاکیش | صندوق سرمایه‌گذاری مشترک ایساتیس پویای یزد | isatisfund.com
10630 | در سهام | حسابرسی بهمند | ندارد | مشاور سرمایه گذاری تامین سرمایه نوین | صندوق سرمایه‌گذاری مشترک بانک اقتصاد نوین | fund.enovinbourse.ir
10767 | مختلط | موسسه حسابرسی و خدمات مدیریت ارقام نگر آریا | ندارد | سبدگردان آبان | صندوق سرمایه‌گذاری مشترک پارس | pars.abanbroker.com
10600 | در سهام | موسسه حسابرسی فریوران راهبرد | ندارد | شرکت سبد گردان انتخاب مفید | صندوق سرمایه‌گذاری مشترک پیشتاز | pishtazfund.com
10851 | در سهام | موسسه حسابرسی فراز مشاور دیلمی پور | ندارد | شرکت سبد گردان انتخاب مفید | صندوق سرمایه‌گذاری مشترک پیشرو | pishrofund.com
11149 | در سهام | مشاور سرمایه گذاری سهم آشنا | ندارد | شرکت مشاور سرمایه گذاری آرمان آتی | صندوق سرمایه‌گذاری مشترک سبحان | sobhanfund.ir
10764 | در سهام | مؤسسه حسابرسی و خدمات مدیریت شهود امین | ندارد | سبدگردان اندیشه صبا | صندوق سرمایه‌گذاری مشترک صبا | fund.sababroker.com
10720 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسی آزمودگان | ندارد | شرکت کارگزاری بانک صنعت و معدن | صندوق سرمایه‌گذاری مشترک صنعت و معدن | smfund.ir
11463 | در سهام | موسسه حسابرسی و خدمات مدیریت آزموده کاران | ندارد | سبدگردان الماس | صندوق سرمایه‌گذاری مشترک گنجینه ارمغان الماس | armaghanalmasfund.com
11411 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسی کارای پارس | شرکت تامین سرمایه لوتوس پارسیان | سبدگردان الماس | صندوق سرمایه‌گذاری مشترک گنجینه الماس پایدار | almaspaidarfund.com
11222 | مختلط | موسسه حسابرسی و خدمات مالی فاطر | گروه مالی مهر اقتصاد | تامین سرمایه امید | صندوق سرمایه‌گذاری مشترک گنجینه مهر | www.ganjinehfund.meibourse.com
11384 | در سهام | حسابرسی هوشیار ممیز | ندارد | کارگزاری مبین سرمایه | صندوق سرمایه‌گذاری مشترک مبین سرمایه | fund.mobinsb.com
11691 | مختلط | موسسه حسابرسی فریوران راهبرد | نامشخص نامشخص | شرکت سبد گردان انتخاب مفید | صندوق سرمایه‌گذاری مشترک مدرسه کسب و کار صوفی رازی | razifund.com
11141 | در سهام | مؤسسه حسابرسی و خدمات مدیریت آزموده کاران ــ حسابد | بانک انصار | تامین سرمایه امید | صندوق سرمایه‌گذاری مشترک نوید انصار | navidansarfund.ir
11314 | در سهام | مشاور سرمایه گذاری ایرانیان تحلیل فارابی | ندارد | شرکت سبدگردان آبان | صندوق سرمایه‌گذاری مشترک نیکوکاری ندای امید | omid.abanbroker.com
11131 | مختلط | شاخص اندیشان | ندارد | کارگزاری بانک صنعت و معدن (سهامی خاص) | صندوق سرمایه‌گذاری مشترک کوثر | kowsarfund.com
11297 | در سهام | موسسه حسابرسی و خدمات مدیریت ارقام نگر آریا | ندارد | سبدگردان آبان | صندوق سرمایه‌گذاری مشترک یکم آبان | aban.aban.net
11090 | در اوراق بهادار با درآمد ثابت | مشاورسرمایه گذاری ایرانیان تحلیل فارابی | ندارد | شرکت کارگزاری بانک رفاه | صندوق سرمایه‌گذاری نگین رفاه | nrfund.ir
11859 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسی هوشیار ممیز | سایر سرمایه گذاران | شرکت سبد گردان مانی | صندوق قابل معامله مانی | manifunds.ir
11772 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي هوشيار مميز | ندارد | شركت سبدگردان نوويرا | طلای سرخ نو ویرا | www.ngmf.ir
11378 | در سهام | حسابرسي شاخص انديشان |  | تامين سرمايه تمدن | قابل معامله آتیه درخشان مس | www.armanmesetf.com
11409 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي هوشيار مميز |  | شركت مشاور سرمايه گذاري آرمان آتي | قابل معامله آرمان آتی کوثر | www.aaketf.com
11729 | در سهام | موسسه حسابرسي فراز مشاور ديلمي پور | ندارد | شركت مشاور سرمايه گذاري معيار | قابل معامله آوای معیار | http://www.avayemeyar.ir
11712 | در سهام | موسسه حسابرسي شاخص انديشان | ندارد | شركت سبدگردان اقتصاد بيدار | قابل معامله ارزش آفرین بیدار | http://arzesh.ebb.ir
10920 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي آزمودگان | ندارد | شركت تأمين سرمايه نوين | قابل معامله ارمغان ایرانیان | http://www.armaghanfund.ir
11315 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي فريوران راهبرد |  | تامين سرمايه لوتوس پارسيان | قابل معامله اعتماد آفرين پارسيان | http://eap-fund.com/index.do
11725 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي شاخص انديشان |  | شركت سبدگردان داريك پارس | قابل معامله اعتماد داریک | http://www.etemaddarik.ir
11260 | در سهام | مشاور سرمايه گذاري سهم آشنا | ندارد | سبدگردان تدبير | قابل معامله امين تدبيرگران فردا | http://fardaetf.tadbirfunds.com
11588 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي هوشيار مميز | ندارد | شركت سبد گردان انديشه صبا | قابل معامله اندیشه ورزان صبا تأمین | www.sast.sababroker.com
11569 | در اوراق بهادار با درآمد ثابت | مؤسسه حسابرسي آزموده كاران | ندارد | شركت سبدگردان تصميم نگار ارزش آفرينان | قابل معامله با درآمد ثابت تصمیم | http://www.tasmimfixedincom.ir
11459 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي هوشيار مميز |  | مشاور سرمايه گذاري پرتو آفتاب كيان | قابل معامله با درآمد ثابت کيان | http://kianfunds1.com
11197 | در سهام | موسسه حسابرسي و خدمات مديريت آزموده كاران | ندارد | شركت تامين سرمايه اميد | قابل معامله بذر امید آفرین | http://www.bazreomidfund.ir
11470 | در سهام | موسسه حسابرسي و خدمات مديريت آزموده كاران | ندارد | سبدگردان پاداش سرمايه | قابل معامله پاداش سرمایه پارس | www.armanmesetf.com
11745 | در سهام | موسسه حسابرسي ارقام نگر آريا | ندارد ? ندارد | شركت تامين سرمايه نوين | قابل معامله پالایشی یکم | http://www.p1fund.ir
11673 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي فراز مشاور ديلمي پور | ندارد | شركت مشاور سرمايه گذاري معيار | قابل معامله توازن معیار | http://meyarfund.com
11874 | در سهام | موسسه حسابرسي هدف نوين نگر | ندارد | سبدگردان ويستا | قابل معامله ثبات ویستا | www.sobatvista.ir
11660 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي و خدمات مديريت سامان پندار | ندارد | شرکت سبدگردان الگوریتم | قابل معامله دارا الگوریتم | http://darafund.ir
11774 | در سهام | موسسه حسابرسي و خدمات مديريت ارقام نگر آريا | ندارد | سبدگردان كوروش | قابل معامله زرین کوروش | www.zarinfunds.com
11722 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي شاخص انديشان | ندارد | شركت سبدگردان اقتصاد بيدار | قابل معامله سپر سرمایه بیدار | http://separ.ebb.ir
11196 | مختلط | موسسه حسابرسي بهمند |  | تأمين سرمايه نوين | قابل معامله سپهر انديشه نوين | http://www.sepehrnovin.ir
11340 | در اوراق بهادار با درآمد ثابت | شركت مشاور سرمايه گذاري ايرانيان تحليل فارابي |  | شركت مشاور سرمايه گذاري امين نيكان آفاق | قابل معامله سپهر خبرگان نفت | http://www.khobregan-etf.com
11183 | در سهام | شركت مشاور سرمايه گذاري سهم آشنا | ندارد | شركت سبدگردان كاريزما | قابل معامله سپهر کاریزما | http://www.scetf.ir/
11649 | در سهام | موسسه حسابرسي شاخص انديشان | ندارد ? ندارد | شركت مشاور سرمايه گذاري ترنج | قابل معامله سرو سودمند مدبران | Sarv.fund
11773 | در سهام | موسسه حسابرسي و خدمات مديريت آزموده كاران | ندارد | شركت سبدگردان داريك پارس | قابل معامله فراز داریک | www.farazdarik.ir
11323 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي سامان پندار |  | كارگزاري بانك آينده(سهامي خاص) | قابل معامله گنجينه آينده روشن | http://www.ayandehfund.com
11341 | در سهام | موسسه حسابرسي و خدمات مالي و مديريت ايران مشهود |  | سبدگردان آگاه | قابل معامله هستی بخش آگاه | http://www.hbagahfund.com
11767 | در سهام | موسسه حسابرسي شاخص انديشان | ندارد | شركت سبد گردان آگاه | قابل معامله همای آگاه | www.homayeagah.ir
11709 | در سهام | سازمان حسابرسي | ندارد | شركت تامين سرمايه بانك مسكن | قابل معامله واسطه گری مالی یکم | http://www.fi1fund.com
11838 | در سهام | موسسه حسابرسي هوشيار مميز | ندارد | سبدگردان سهم آشنا | قابل معامله کامیاب آشنا | http://www.kamyabfund.ir
11698 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي آزمودگان | ندارد | شركت سبد گردان آگاه | قابل معامله یاقوت آگاه | http://yaghootfund.ir
11780 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي هوشيار مميز | ندارد | مشاور سرمايه گذاري ديدگاهان نوين | گروه زعفران سحرخیز | www.saharkhizfund.com
10915 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي سامان پندار | بانك آينده | شركت كارگزاري بانك آينده | گسترش فردای ایرانیان | http://www.gostareshfund.ir
11098 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي آزموده كاران | بانك پارسيان | تامين سرمايه لوتوس پارسيان | لوتوس پارسیان | http://parsianlotusfund.com
11842 | مختلط | مؤسسه حسابرسي و خدمات مديريت سامان پندار | ندارد | سبدگردان كاريزما | مختلط کاریزما | http://www.sepehrati.com/
11220 | در سهام | موسسه حسابرسي فراز مشاور | ضامن | سبدگردان سرمايه و دانش | مشترك افق | http://www.ofoghfund.com
10596 | در سهام | موسسه حسابرسي و خدمات مديريت ارقام نگر آريا | سرمايه گذاري توسعه ملي - ضامن | كارگزاري بانك ملي ايران - مدير | مشترك كارگزاري بانك ملي ايران | http://www.bmimf.com
10616 | در سهام | موسسه حسابرسي و خدمات مالي و مديريت ايران مشهود | ندارد | شركت سبدگردان آگاه | مشترک آگاه | http://www.agah-fund.ir
11338 | در اوراق بهادار با درآمد ثابت | شركت ارقام نگر آريا | ندارد | كارگزاري بانك خاورميانه | مشترک افق کارگزاری بانک خاورمیانه | ofoghfund.mebbco.com
11148 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي ايران مشهود | ندارد | شركت سبدگردان اميد نهايت نگر | مشترک البرز | http://www.alborzfunds.com
11168 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي ايران مشهود | پارس آريان | شركت مشاور سرمايه گذاري ارزش پرداز آريان | مشترک اندیشه فردا | http://www.andishefardafund.com/
11234 | در سهام | موسسه حسابرسي و خدمات مالي هميار حساب | ندارد | سبدگردان اميد نهايت نگر | مشترک بانک خاورمیانه | http://www.mebfund.ir
10766 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي شاخص انديشان | تامين سرمايه بانك مسكن | تامين سرمايه بانك مسكن | مشترک بانک مسکن | maskanibfund.com
10719 | در سهام | موسسه حسابرسي فاطر | ندارد ? ندارد | شركت سبدگردان پاداش سرمايه | مشترک بورسیران | http://www.bifund.ir
10589 | در سهام | موسسه حسابرسي و خدمات مالي و مديريت ايران مشهود | ندارد | شركت سبدگردان اميد نهايت نگر | مشترک پویا | http://www.iranfunds.com
10801 | در سهام | مشاور سرمايه گذاري سهم آشنا | ندارد | سبدگردان تدبير | مشترک تدبیرگران فردا | http://farda.tadbirfunds.com
11182 | در سهام | موسسه حسابرسي و خدمات مديريت ارقام نگر آريا | ندارد | كارگزاري بانك ملي ايران | مشترک توسعه ملی | http://www.tmmf.ir
11186 | در سهام | موسسه حسابرسي و خدمات مالي هميار حساب | ندارد | شركت كارگزاري بورسيران | مشترک دماسنج | http://www.dsfund.ir/
11235 | در سهام | موسسه حسابرسي هدف نوين نگر | شركت بيمه سامان | شركت تامين سرمايه كاردان | مشترک رشد سامان | www.roshdfund.com
11239 | مختلط | موسسه حسابرسي و خدمات مديريت سامان پندار | شركت تأمين سرمايه سپهر (سهامي خاص) | شركت تأمين سرمايه سپهر (سهامي خاص) | مشترک سپهر آتی | http://www.sepehrati.com/
11217 | در اوراق بهادار با درآمد ثابت | مشاور سرمايه گذاري سهم آشنا | تامين سرمايه لوتوس پارسيان | سبدگردان تدبير | مشترک سپهر تدبیرگران | http://www.sepehr.tadbirfunds.com
11442 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي فراز مشاور ديلمي | ندارد | شركت سبدگردان هدف | مشترک صبای هدف | www.hadafmf.ir
10830 | در سهام | مؤسسه حسابرسي آزمودگان | ندارد ? ندارد | مشاور سرمايه گذاري هدف حافظ | مشترک عقیق | http://aghighfund.com
10748 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي شاخص انديشان | تامين سرمايه نوين | تامين سرمايه نوين | مشترک فراز اندیش نوین | http://farazandishnovin.ir/
10896 | در سهام | موسسه حسابرسي و خدمات مديريت سامان پندار | گروه خدمات بازار سرمايه الگوريتم | شركت سبدگردان الگوريتم | مشترک مانا الگوریتم | http://www.mana.fund/
10787 | در سهام | موسسه حسابرسي رازدار | ندارد | سبدگردان سرآمد بازار | مشترک نقش جهان | www.jahanfund.com
10763 | مختلط | موسسه حسابرسي و بهبود سيستماي مديريت حسابرسين | ندارد | كارگزاري نوانديشان بازار سرمايه | مشترک نواندیشان | http://enoandishan.net/
10771 | در سهام | موسسه حسابرسي هدف نوين نگر | ندارد | تامين سرمايه نوين | مشترک نوین پایدار | http://www.novinfund.com
10581 | در اوراق بهادار با درآمد ثابت | شركت مشاور سرمايه گذاري سهم آشنا | بانك كارآفرين | كارگزاري بانك كارآفرين | مشترک کارگزاری کارآفرین | http://karafarinfunds.com
11095 | در سهام | موسسه حسابرسي رازدار | ندارد | شركت سبدگردان كاريزما | مشترک کاریزما | http://charismafund.com
10615 | مختلط | شركت مشاور سرمايه گذاري ايرانيان تحليل فارابي | تامين سرمايه كاردان | تامين سرمايه كاردان | مشترک کیمیای کاردان | kimia.kardan.ir
10639 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي شاخص انديشان | ندارد | شركت تأمين سرمايه نوين | مشترک یکم ایرانیان | http://www.iranianfund.com
10872 | در سهام | موسسه حسابرسي هدف نوين نگر | بانك سامان | شركت تامين سرمايه كاردان | مشترک یکم سامان | http://www.samanfund1.com
11280 | در سهام | موسسه حسابرسي شاخص انديشان | شركت تامين سرمايه نوين | شركت تامين سرمايه نوين | میعاد ایرانیان | http://www.miadfund.ir/index.do
10923 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي آزمودگان | ندارد | شركت تأمين سرمايه نوين | نهال سرمایه ایرانیان | http://www.sarmayefund.ir
11883 | در سهام | موسسه حسابرسي هدف نوين نگر | ندارد | سبدگردان كاريزما | نوع دوم کارا | kara.charisma.ir
11304 | مختلط | مشاور سرمايه گذاري سهم آشنا | موسسه بنياد بركت | سبدگردان تدبير | نیکوکاری ایتام برکت | http://barakat.tadbirfunds.com
11380 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي و خدمات مديريت رهيافت و همكاران | تامين سرمايه تمدن | سبدگردان سهم آشنا | نیکوکاری جايزه علمي فناوري پيامبر اعظم(ص) | http://saf7s.rhbroker.com/index.do
11290 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي و بهبود سيستم هاي مديريتي حسابرسين | ندارد | تامين سرمايه لوتوس پارسيان | نیکوکاری دانشگاه الزهرا | http://www.alzahrafund.ir
11256 | در اوراق بهادار با درآمد ثابت | شركت مشاور سرمايه گذاري سهم آشنا | ندارد | سبدگردان كاريزما | نیکوکاری دانشگاه تهران | http://www.utfund.ir
11476 | در اوراق بهادار با درآمد ثابت | حسابرسي و بهبود سيستمهاي مديريت حسابرسين | ندارد | تامين سرمايه لوتوس پارسيان | نیکوکاری لوتوس رویان | http://www.lrfund.ir
11381 | مختلط | حسابرسي و خدمات مديريت رهيافت و همكاران | ندارد | مشاور سرمايه گذاري ارزش پرداز آريان | نیکوکاری میراث ماندگار پاسارگاد | http://www.mirasfund.com/
11198 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي هوشيار مميز | بانك حكمت ايرانيان (سهامي عام) | سبدگردان سهم آشنا | نیکوکاری ورزشی پرسپولیس | http://perspolisfund.ir
11427 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي رازدار | ندارد | شركت سبدگردان كاريزما | نیکوکاری کشتی ورزش ملی ایران | http://www.koshtifund.ir
11258 | مختلط | مشاور سرمايه گذاري ايرانيان تحليل فارابي | ضامن نقد شوندگي | شركت مشاور سرمايه گذاري نيكي گستر | نیکی گستران | http://nikigostaranfund.com
11273 | در سهام | موسسه حسابرسي و خدمات مديريت سامان پندار | شركت تأمين سرمايه سپهر | شركت تأمين سرمايه سپهر | همیان سپهر | http://www.hsfund.ir
10843 | در سهام | موسسه حسابرسي آرمان آروين پارس | ندارد | كارگزاري پارسيان | کارگزاری پارسیان | www.fund.parsianbroker.com
10743 | در سهام | موسسه حسابرسي بهمند | ندارد | سبدگردان فارابي | یکم اکسیر فارابی | http://www.farabifund.com
10934 | مختلط | موسسه حسابرسي و خدمات مالي و مديريت ايران مشهود | ندارد | شركت سبدگردان آگاه | یکم نیکوکاری آگاه | http://1nikokarifund.com
10837 | در اوراق بهادار با درآمد ثابت | موسسه حسابرسي بهراد مشار | ندارد | كارگزاري بانك كشاورزي | یکم کارگزاری بانک کشاورزی | http://fund1.agribourse.com